==> Iacorner_0.22_dev.zip: an/db/postgres/sql/01_TABLE/AN12S.sql <==
/**************************************************************************/
/* AN12 ( アンケート回答明細 )                                            */
/*                                                                        */
/* Created : 2010/09/27 16:41:33                                          */
/**************************************************************************/
CREATE TABLE AN12 (
   NOKAITO   VARCHAR(10)                  NOT NULL                 /* 1  回答番号     */
 , NOMEISAI  INTEGER          DEFAULT 0   NOT NULL                 /* 2  回答明細番号 */
 , USERID    VARCHAR(10)                  NOT NULL                 /* 3  ユーザーID   */
 , CDANK     VARCHAR(10)                  NOT NULL                 /* 4  アンケートC  */
 , CDSITSU   VARCHAR(10)                  NOT NULL                 /* 5  質問C        */
 , KVAL      VARCHAR(4000)                NOT NULL                 /* 6  回答値       */
 , KNAME     VARCHAR(4000)                                         /* 7  回答名称     */
 , FGOTHER   VARCHAR(1)       DEFAULT '0' NOT NULL                 /* 8  その他F      */
 , SUPOINT   INTEGER          DEFAULT 0   NOT NULL                 /* 9  得点         */
 , FGCORRECT VARCHAR(1)                                            /* 10 正解F        */
 , UNIQ      SERIAL                                PRIMARY KEY     /* 11 ユニークキー */
 , FGJ       VARCHAR(1)       DEFAULT '1' NOT NULL                 /* 12 状態フラグ   */
 , DYSET     VARCHAR(14)                                           /* 13 登録日時     */
 , PGSET     VARCHAR(10)                                           /* 14 作成PG       */
 , PGPSET    VARCHAR(10)                                           /* 15 作成親PG     */
 , USRSET    VARCHAR(10)                                           /* 16 作成社員     */
 , DYUPD     VARCHAR(14)                                           /* 17 更新日時     */
 , PGUPD     VARCHAR(10)                                           /* 18 更新PG       */
 , PGPUPD    VARCHAR(10)                                           /* 19 更新親PG     */
 , USRUPD    VARCHAR(10)                                           /* 20 更新者       */
);

==> Iacorner_0.23_dev.zip: an/db/postgres/sql/01_TABLE/AN12S.sql <==
/**************************************************************************/
/* AN12 ( アンケート回答明細 )                                            */
/*                                                                        */
/* Created : 2010/10/08 09:29:32                                          */
/**************************************************************************/
CREATE TABLE AN12 (
   NOKAITO   VARCHAR(10)                  NOT NULL                 /* 1  回答番号     */
 , NOMEISAI  INTEGER          DEFAULT 0   NOT NULL                 /* 2  回答明細番号 */
 , USERID    VARCHAR(10)                  NOT NULL                 /* 3  ユーザーID   */
 , CDANK     VARCHAR(10)                  NOT NULL                 /* 4  アンケートC  */
 , CDSITSU   VARCHAR(10)                  NOT NULL                 /* 5  質問C        */
 , KVAL      VARCHAR(4000)                NOT NULL                 /* 6  回答値       */
 , KNAME     VARCHAR(4000)                                         /* 7  回答名称     */
 , FGOTHER   VARCHAR(1)       DEFAULT '0' NOT NULL                 /* 8  その他       */
 , SUPOINT   INTEGER          DEFAULT 0   NOT NULL                 /* 9  得点         */
 , FGCORRECT VARCHAR(1)                                            /* 10 正解         */
 , UNIQ      SERIAL                                PRIMARY KEY     /* 11 ユニークキー */
 , FGJ       VARCHAR(1)       DEFAULT '1' NOT NULL                 /* 12 状態フラグ   */
 , DYSET     VARCHAR(14)                                           /* 13 登録日時     */
 , PGSET     VARCHAR(10)                                           /* 14 作成PG       */
 , PGPSET    VARCHAR(10)                                           /* 15 作成親PG     */
 , USRSET    VARCHAR(10)                                           /* 16 作成社員     */
 , DYUPD     VARCHAR(14)                                           /* 17 更新日時     */
 , PGUPD     VARCHAR(10)                                           /* 18 更新PG       */
 , PGPUPD    VARCHAR(10)                                           /* 19 更新親PG     */
 , USRUPD    VARCHAR(10)                                           /* 20 更新者       */
);
